==> tdelibs-trinity-14.0.6.tar.xz: tdelibs-trinity-14.0.6/tdeabc/vcard/include/VCardLangValue.h <==
/*
	libvcard - vCard parsing library for vCard version 3.0
	
	Copyright (C) 1999 Rik Hemsley rik@kde.org
	
  Permission is hereby granted, free of charge, to any person obtaining a copy
  of this software and associated documentation files (the "Software"), to
  deal in the Software without restriction, including without limitation the
  rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
  sell copies of the Software, and to permit persons to whom the Software is
  furnished to do so, subject to the following conditions:

  The above copyright notice and this permission notice shall be included in
  all copies or substantial portions of the Software.

  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
  AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
  ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
  WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/

#ifndef  LANGVALUE_H
#define  LANGVALUE_H

#include <tqcstring.h>
#include <tqstrlist.h>

#include <VCardValue.h>

namespace VCARD
{

class KVCARD_EXPORT LangValue : public Value
{
#include "LangValue-generated.h"
	
	TQCString primary();
	TQStrList subtags();
	
	void setPrimary(const TQCString &);	
	void setSubTags(const TQStrList &);
	
	TQCString primary_;
	TQStrList subtags_;
};

}

#endif

==> tdelibs-trinity-14.1.4.tar.xz: tdelibs-trinity-14.1.4/tdeabc/vcard/include/VCardLangValue.h <==
/*
	libvcard - vCard parsing library for vCard version 3.0
	
	Copyright (C) 1999 Rik Hemsley rik@kde.org
	
  Permission is hereby granted, free of charge, to any person obtaining a copy
  of this software and associated documentation files (the "Software"), to
  deal in the Software without restriction, including without limitation the
  rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
  sell copies of the Software, and to permit persons to whom the Software is
  furnished to do so, subject to the following conditions:

  The above copyright notice and this permission notice shall be included in
  all copies or substantial portions of the Software.

  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
  AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
  ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
  WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/

#ifndef  LANGVALUE_H
#define  LANGVALUE_H

#include <tqcstring.h>
#include <tqstrlist.h>

#include <VCardValue.h>

namespace VCARD
{

class KVCARD_EXPORT LangValue : public Value
{
	public:
		LangValue();
		LangValue(const LangValue&);
		LangValue(const TQCString&);
		LangValue & operator = (LangValue&);
		LangValue & operator = (const TQCString&);
		bool operator ==(LangValue&);
		bool operator !=(LangValue& x) {return !(*this==x);}
		bool operator ==(const TQCString& s) {LangValue a(s);return(*this==a);} 
		bool operator != (const TQCString& s) {return !(*this == s);}

		virtual ~LangValue();
		void parse() {if(!parsed_) _parse();parsed_=true;assembled_=false;}

		void assemble() {if(assembled_) return;parse();_assemble();assembled_=true;}

		void _parse();
		void _assemble();
		const char * className() const { return "LangValue"; }

		TQCString primary();
		TQStrList subtags();

		void setPrimary(const TQCString &);	
		void setSubTags(const TQStrList &);

		TQCString primary_;
		TQStrList subtags_;
};

}

#endif
